@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from enum import auto, Enum
+from enum import Enum, auto
 
 
 class StatType(Enum):
