@@ -20,7 +20,3 @@ class AwsUtils:
     @classmethod
     def __open_boto_session__(cls) -> Session:
         return boto3.session.Session()
-
-
-if __name__ == "__main__":
-    print(AwsUtils.get_client())
